@@ -186,7 +186,7 @@ class HierarchicalLDA(object):
 
     def estimate(self, num_samples, display_topics=50, n_words=5, with_weights=True):
 
-        print 'HierarchicalLDA sampling\n'
+        print('HierarchicalLDA sampling\n')
         for s in range(num_samples):
 
             sys.stdout.write('.')
@@ -198,9 +198,9 @@ class HierarchicalLDA(object):
                 self.sample_topics(d)
 
             if (s > 0) and ((s+1) % display_topics == 0):
-                print " %d" % (s+1)
+                print(f" {s+1}")
                 self.print_nodes(n_words, with_weights)
-                print
+#                 print
 
     def sample_path(self, d):
 
@@ -384,7 +384,7 @@ class HierarchicalLDA(object):
         out = '    ' * indent
         out += 'topic=%d level=%d (documents=%d): ' % (node.node_id, node.level, node.customers)
         out += node.get_top_words(n_words, with_weights)
-        print out
+        print(out)
         for child in node.children:
             self.print_node(child, indent+1, n_words, with_weights)
 
@@ -411,4 +411,4 @@ def load_corpus(file_name):
                     idx, word = tokens
                     doc.append(int(idx))
             corpus.append(doc)
-        return corpus
\ No newline at end of file
+        return corpus
